{
  pkgs,
  lib,
  ...
}:
{
  home.username = "blue";
  home.homeDirectory = "/home/blue";

  imports = [
    ./hyprland.nix
    ./waybar.nix
    ./swaync.nix
    ./hyprlock.nix
    ./fish.nix
    ./eza.nix
    ./nvf.nix
    ./git.nix
    ./stylix.nix
    ./direnv.nix
    ./librewolf.nix
    ./zellij.nix
    ./obs-studio.nix
    ./packages.nix
  ];

  home.stateVersion = "24.05";

  services.gnome-keyring.enable = true; # used for nextcloud-client

  home.sessionVariables = {
    DEFAULT_BROWSER = "${lib.getExe pkgs.librewolf}"; 
    # Allow XWayland apps to not be weird after turning off xwayland scaling in hyprland.conf
    GDK_SCALE = 1;
    XCURSOR_SIZE = 24;
    # Set hyprshot save directory
    HYPRSHOT_DIR = "$HOME/Pictures/Screenshots";
    # Set default editor
    EDITOR = "nvim";
    NIXOS_OZONE_WL = 1;
    LD_LIBRARY_PATH = "${pkgs.libGL}/lib:${pkgs.gtk3}/lib:${pkgs.glib.out}/lib:${pkgs.xorg.libXtst}/lib";
    scripts = "/home/blue/nixconf/scripts";
  };

  xdg.mimeApps = {
    enable = true;
    defaultApplications = {
      "text/html" = "librewolf.desktop";
      "x-scheme-handler/http" = "librewolf.desktop";
      "x-scheme-handler/https" = "librewolf.desktop";
      "x-scheme-handler/about" = "librewolf.desktop";
      "x-scheme-handler/unknown" = "librewolf.desktop";
    };
  };

  # Let Home Manager install and manage itself.
  programs.home-manager.enable = true;

  programs.tmux.enable = true;
  programs.zoxide = {
    enable = true;
    enableZshIntegration = true;
  };

  programs.btop.enable = true;
  programs.btop.package = pkgs.stable.btop-rocm;

  # Add support for bluetooth headset media controls
  services.mpris-proxy.enable = true;

  programs.alacritty = {
    enable = true;
    package = pkgs.alacritty;
    settings = {
      window.dimensions = {
        lines = 3;
        columns = 200;
      };
    };
  };
}
